@@ -11,6 +11,7 @@ from .employee import Employee
 from .employee import EmployeeRead
 from .employee import EmployeeWrite
 from .facet import FacetClass
+from .organisation import OrganisationRead
 from .organisation_unit import OrganisationUnit
 from .organisation_unit import OrganisationUnitRead
 from .organisation_unit import OrganisationUnitWrite
@@ -25,6 +26,7 @@ __all__ = [
     "EmployeeRead",
     "EmployeeWrite",
     "FacetClass",
+    "OrganisationRead",
     "OrganisationUnit",
     "OrganisationUnitRead",
     "OrganisationUnitWrite",
