@@ -9,6 +9,8 @@
 from typing import Optional
 from uuid import UUID
 
+from pydantic import Field
+
 from ramodels.mo._shared import MOBase
 
 # --------------------------------------------------------------------------------------
@@ -17,16 +19,14 @@ from ramodels.mo._shared import MOBase
 
 
 class FacetClass(MOBase):
-    """Payload model for Klasses to be created under the given Facet.
+    """Payload model for Klasses to be created under the given Facet."""
 
-    Attributes:
-        name (str): Human-readable name
-        user_key (str): Short, unique key
-        scope (Optional[str]): Representation of Klasse type
-        org_uuid (UUID): Organisation UUID
-    """
-
-    name: str
-    user_key: str
-    scope: Optional[str]
-    org_uuid: UUID
+    facet_uuid: UUID = Field(
+        description="UUID of the facet for which the Klasse should be created."
+    )
+    name: str = Field(description="Name of the Klasse.")
+    user_key: str = Field(description="Short, unique key.")
+    scope: Optional[str] = Field(description="Scope of the created Klasse.")
+    org_uuid: UUID = Field(
+        description="UUID of the organisation for which the Klasse should be created."
+    )
