@@ -30,25 +30,25 @@ from .details import OrgUnitDetails
 class OrganisationUnitBase(MOBase):
     """A MO organisation unit object."""
 
-    type_: Literal["org_unit"] = Field(
-        "org_unit", alias="type", description="The object type."
-    )
+    type_: str = Field("org_unit", alias="type", description="The object type.")
     name: str = Field(description="Name of the created organisation unit.")
     validity: Validity = Field(description="Validity of the created organisation unit.")
 
 
 class OrganisationUnitRead(OrganisationUnitBase):
-    parent: Optional[UUID] = Field(description="UUID of the parent organisation unit.")
+    parent_uuid: Optional[UUID] = Field(
+        description="UUID of the parent organisation unit."
+    )
     org_unit_hierarchy: Optional[UUID] = Field(
         description="UUID of the organisation unit hierarchy."
     )
-    org_unit_type: Optional[UUID] = Field(
+    unit_type_uuid: Optional[UUID] = Field(
         description="UUID of the organisation unit type."
     )
-    org_unit_level: Optional[UUID] = Field(
+    org_unit_level_uuid: Optional[UUID] = Field(
         description="UUID of the organisation unit level."
     )
-    time_planning: Optional[UUID] = Field(
+    time_planning_uuid: Optional[UUID] = Field(
         description="UUID of the time planning object."
     )
 
